OrbClientPlatform

Struct OrbClientPlatform 

pub struct OrbClientPlatform { /* private fields */ }
Describes a Slint platform that is based on OrbClient and so can run on also on Redox OS.

Implementations

Source

impl OrbClientPlatform

pub fn new() -> Self

Returns a new platform object.